@@ -22,7 +22,9 @@ def compute_target_lengths(targets):
 
 
 def select_contains_alias_call(expression):
-    if not hasattr (expression.value, "func") or not hasattr(expression.value.func, "attrname"):
+    if not hasattr(expression.value, "func") or not hasattr(
+        expression.value.func, "attrname"
+    ):
         return False
     if expression.value.func.attrname == "select":
         for arg in expression.value.args:
@@ -33,7 +35,9 @@ def select_contains_alias_call(expression):
 
 
 def select_contains_cast_call(expression):
-    if not hasattr (expression.value, "func") or not hasattr(expression.value.func, "attrname"):
+    if not hasattr(expression.value, "func") or not hasattr(
+        expression.value.func, "attrname"
+    ):
         return False
     if expression.value.func.attrname == "select":
         for arg in expression.value.args:
@@ -42,17 +46,55 @@ def select_contains_cast_call(expression):
                     return True
     return False
 
+
 def module_contains_display(expression):
     contains_func_attribute = hasattr(expression.value, "func")
     contains_attrname = hasattr(expression.value.func, "attrname")
-    contains_display_attr = expression.value.func.attrname == "display"
+    try:
+        contains_display_attr = expression.value.func.attrname == "display"
+    except AttributeError:
+        contains_display_attr = False
     contains_display_func = False
     for arg in expression.value.args:
         if isinstance(arg, astroid.nodes.Call):
             if arg.func.attrname == "display":
                 contains_display_func = True
-    return (contains_func_attribute and contains_attrname and contains_display_attr) or (contains_func_attribute and contains_display_func)
-        
+    return (
+        contains_func_attribute and contains_attrname and contains_display_attr
+    ) or (contains_func_attribute and contains_display_func)
+
+
+def module_contains_show(expression):
+    contains_func_attribute = hasattr(expression.value, "func")
+    contains_attrname = hasattr(expression.value.func, "attrname")
+    try:
+        contains_show_attr = expression.value.func.attrname == "show"
+    except AttributeError:
+        contains_show_attr = False
+    contains_show_func = False
+    for arg in expression.value.args:
+        if isinstance(arg, astroid.nodes.Call):
+            if arg.func.attrname == "show":
+                contains_show_func = True
+    return (contains_func_attribute and contains_attrname and contains_show_attr) or (
+        contains_func_attribute and contains_show_func
+    )
+
+
+def module_contains_print(expression):
+    contains_func_attribute = hasattr(expression.value, "func")
+    # contains_attrname = hasattr(expression.value.func, "attrname")
+    # try:
+    #     contains_display_attr = expression.value.func.attrname == "print"
+    # except AttributeError:
+    #     contains_display_attr = False
+    contains_print_func = False
+    for arg in expression.value.args:
+        if isinstance(arg, astroid.nodes.Call):
+            if arg.func.attrname == "print":
+                contains_print_func = True
+    return contains_func_attribute and contains_print_func
+
 
 def is_line_split(val):
     line = val.lineno
@@ -142,23 +184,23 @@ def get_length(arg):
             total_length += get_length(value)
         return total_length
     if isinstance(arg, astroid.nodes.Subscript):
-        base_length = 2 # brackets
+        base_length = 2  # brackets
         total_length = base_length + get_length(arg.value) + get_length(arg.slice)
         return total_length
     if isinstance(arg, astroid.nodes.JoinedStr):
-        base_length = 3 # quotes and 'f'
+        base_length = 3  # quotes and 'f'
         total_length = 0
         for value in arg.values:
             total_length += get_length(value)
         total_length += base_length
         return total_length
     if isinstance(arg, astroid.nodes.FormattedValue):
-        base_length = 3 # quotes and 'f'
+        base_length = 3  # quotes and 'f'
         total_length = 0
         total_length += base_length + get_length(arg.value)
         return total_length
     if isinstance(arg, astroid.nodes.Starred):
-        base_length = 1 # '*'
+        base_length = 1  # '*'
         total_length = get_length(arg.value)
         total_length += base_length
         return total_length
@@ -186,7 +228,7 @@ def get_length(arg):
         total_length += lower_length + step_length + upper_length + number_of_colon
         return total_length
     if isinstance(arg, astroid.nodes.UnaryOp):
-        base_length = 1 # operator
+        base_length = 1  # operator
         total_length = len(arg.operand)
         total_length += base_length
         return total_length
